pub enum Tensor {
Scalar(f64),
Array(Vec<Tensor>),
}Expand description
A multi-dimensional numerical array.
Tensors can be scalars (single values) or arrays of nested tensors. All leaf values are stored as f64.
Examples
use hedl_core::lex::{parse_tensor, Tensor};
// Scalar
let scalar = Tensor::Scalar(42.0);
assert_eq!(scalar.shape(), vec![]);
assert_eq!(scalar.flatten(), vec![42.0]);
// 1D array
let vec = parse_tensor("[1, 2, 3]").unwrap();
assert_eq!(vec.shape(), vec![3]);
assert!(vec.is_integer());
// 2D matrix
let matrix = parse_tensor("[[1.5, 2.5], [3.5, 4.5]]").unwrap();
assert_eq!(matrix.shape(), vec![2, 2]);
assert!(!matrix.is_integer());Variants
Implementations
Sourceimpl Tensor
impl Tensor
Sourcepub fn is_integer(&self) -> bool
pub fn is_integer(&self) -> bool
Returns true if this tensor contains only integers (no decimal points).
A number is considered an integer if its fractional part is zero.
Examples
use hedl_core::lex::{parse_tensor, Tensor};
let integers = parse_tensor("[1, 2, 3]").unwrap();
assert!(integers.is_integer());
let floats = parse_tensor("[1.5, 2.5]").unwrap();
assert!(!floats.is_integer());Sourcepub fn shape(&self) -> Vec<usize>
pub fn shape(&self) -> Vec<usize>
Returns the shape of the tensor as a vector of dimensions.
Examples
use hedl_core::lex::{parse_tensor, Tensor};
let scalar = Tensor::Scalar(42.0);
assert_eq!(scalar.shape(), vec![]);
let vec = parse_tensor("[1, 2, 3]").unwrap();
assert_eq!(vec.shape(), vec![3]);
let matrix = parse_tensor("[[1, 2], [3, 4]]").unwrap();
assert_eq!(matrix.shape(), vec![2, 2]);Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Tensor
impl<'de> Deserialize<'de> for Tensor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for Tensor